(((kind "manual-section") (section-title "Overview and organization.") (section-body "The course plan document style relies on a complete description of a course plan in terms of lecture lists,
time lists, subject lists, and a number of other parameters. The course description is represented in a single
central Lisp file, the <em>course description file</em>.<p>
Besides the course description file there is one central LAML file which generates the introduction, the overviews, and
the HTML frame pages. The is caled the <em>LAML course file.</em> Besides these two files there exists a file pr. lecture,
typically (but not necessarily) organized in a directory of their own. Finally, there may be other course files with additional
text, which are produced with the course file look using the functions course-page write-course-html-file.

The course plan document styles features a very convenient handling of time. If the course runs perodically and
regularly the determination of the individual lecture times is almost made automatically, see time-list below.
The temporal power of the system is used to generate overviews and calendars (by means of the LAML calandar tool).
We use a separate and simple time-list, external from the other lists, to provide for very easy rescheduling of lectures.<p>

We recommend the following directory and file organization when using the course plan document style:
<pre>
  course-dir
   html (*)
     images  (*)
   internal (*)
   lecture-pages
   course-description.scm
   course.laml
</pre>
All but course.laml and course-description.scm are directories. Only those directories marked by (*) need to have the mentioned names.

We will now describe the role of each of the directories and files:
<ul>
  <li> course-dir: The home directory of the course. May contain many other items. Named by the variable course-dir.
  <li> html: The directory in which all generated HTML files are located. Create this directory yourself.
  <li> html/images: The directory where all gif files will be placed. The necessary gif files will be copied to this directory automatically.
       However, you must create this directory yourself.
  <li> internal: A directory in which some internal files are written.
  <li> lecture-pages: The directory in which to place the individual LAML lecture descriptions.
  <li> course-description.scm: The course description file which must be loaded just after the course-plan style file. You are yourself responsible
       for loading this file.
  <li> course.laml: The LAML file which produces all the overall plans and \"infrastructure\" pages, including the course home page itself.
       This file should also produce the course intoduction file, which must be named course-introduction.
</ul>
The html, html/images, and the internal directories are created automatically by the course-plan system.
In a later section we will show examples and templates of the directories and files.")) ((kind "manual-section") (section-title "The course description.") (section-body "
The definitions in this section must be redefined in the course-description file
which should be located in course-dir, which is defined below. The course description file
must be loaded just after the style loading clause. The central description structures (lists)
are time-list, lecture-description-list, and subject-list.

")) ((kind "manual-page") (description "A list of subject records.
A subject record is a list of (subject-id title subject).
The default is the empty list. Is allowed to be longer or shorter than lecture-description-list.
Entries are looked up via the subject-id.
") (title "subject-list") (form subject-list)) ((kind "manual-page") (description "A list of lecture records. 
A lecture record is the central description of a single lecture in the course, in terms of
a lecture-id, a subject-id (referring to a record in suject-list), exercise time info, plenum time info, and room info.
The list must be of the same length as time-list.
Lecture record description:
  Lecture-id: A symbol identifying a lecture. -
  Subject-id: A symbol identifying a subject in subject list. -
  Exercise-info: A list of (start-displacement length). Displacement relative to lecture start in time-list. Length in seconds. -
  Plenum-info: A list of (start-displacement length). Displacement relative to lecture start in time-list. Length in seconds. -
  Room: A room id string.
") (title "lecture-description-list") (form lecture-description-list)) ((kind "manual-page") (description "A list of times for the individual lectures in the course.
Each time is an integer (the number of seconds since jan. 1, 1970).
Use the function time-encode from the LAML time library to return such a number.
Must be of the same length as lecture-list.
") (title "time-list") (form time-list)) ((kind "manual-page") (description "The title of the course (a string).
Must be defined in the course desciption file.
") (title "course-title") (form course-title)) ((kind "manual-page") (description "A brief, abbreviated course title (a string).
Must be defined in the course desciption file.
") (title "brief-course-title") (form brief-course-title)) ((kind "manual-page") (description "Course semester (a string).
Must be defined in the course desciption file.
") (title "course-semester") (form course-semester)) ((kind "manual-page") (description "Brief course semester (a string).
Must be defined in the course desciption file.
") (title "brief-course-semester") (form brief-course-semester)) ((kind "manual-page") (description "The name of the teacher(s). Defaults to \"The teacher\"
") (title "teacher-name") (form teacher-name)) ((kind "manual-page") (description "The absolute path of the course directory.
Ends in a slash.
Must be defined in the course desciption file.
") (title "course-dir") (form course-dir)) ((kind "manual-page") (description "The prefix of the course URL, pointing at the course directory.
Ends in a slash.
Must be defined in the course desciption file.
") (title "course-url-prefix") (form course-url-prefix)) ((kind "manual-page") (description "A HTML string returning function with standard links from course-plan pages. 
As default, no standard links are defined.
") (title "standard-links") (form (standard-links))) ((kind "manual-page") (description "A function which returns a list of links which go into the overview frame (the leftmost frame of the frameset) of the course home page.
Each element of the list must be a list of the format (\"url\" \"anchor-name\" \"target\"). The target may be \"main\" (for the main, rightmost
window of the frameset) or \"_top\".
Thus this function must return a list of lists.
The links given here are added to some automatically generated links to overviews, calendar, and introduction.
If you want additional general links, redefine the function in the course description file.
As the default, this function returns the empty list.
") (title "general-overview-links") (form (general-overview-links))) ((kind "manual-page") (description "A function which returns trace information. Must return the emtpy string of an HTML comment.
The LAML function html:page uses and expects this function.
You can use the LAML function html-comment when implementing the function. The default implementation returns the empty string.
") (title "tracing-comment") (form (tracing-comment))) ((kind "manual-page") (description "A function which returns meta information, inserted by html:page.
The LAML function html:page uses and expects this function.
Must return a list of property lists of meta information.
The default implementation returns the empty list (no meta information).
") (title "meta-tag-clauses") (form (meta-tag-clauses))) ((kind "manual-page") (description "Return a list with course meta information to be put on any course page.
Similar to the function meta-tag-clauses.
The result of this function is passed more directly to the html:page function via the course-plan document style.
As default no meta descriptions are provided.
") (title "meta-course-contribution") (form (meta-course-contribution))) ((kind "manual-page") (description "The last lecture-number which we want presented now.
Using this variable we can progressively reveal more and more lectures in the course.
Must be defined in the course desciption file.
") (title "last-lecture-number") (form last-lecture-number)) ((kind "manual-page") (description "The pixel width of the overview frame (leftmost frame of course home page).
Default 320.
") (title "overview-pixel-width") (form overview-pixel-width)) ((kind "manual-page") (description "The total pixel width of a calendar. OK for one semester, but problematic for other course spans.
") (title "preferred-calendar-pixel-width") (form preferred-calendar-pixel-width)) ((kind "manual-page") (description "The time (second-count) of the first lecture in the course.
Must be defined in the course desciption file.
") (title "course-start") (form course-start)) ((kind "manual-page") (description "Given the records of this lecture and the next-lecture, return an interval of the exercise time.
Return #f if there are no exercises.
Depends on the model: forskudte velser til nste velsesgang.
This function may return #f in case there is no lectures.
next-lecture-rec may be #f in which case this function also returns #f.
Must be redefined in the course-description-file.
") (title "actual-exercise-interval") (form (actual-exercise-interval this-lecture-rec next-lecture-rec))) ((kind "manual-section") (section-title "Top level course plan functions.") (section-body "
The top level functions used in individual lecture pages (pages describing a single lecture plan in the course)
are init-course-plan and lecture-plan. Besides these, the exercise functions described later are typically found
in a lecture plan file.

")) ((kind "manual-page") (description "The init-course-plan function must be called after all loading is completed, and before any pages are generated.
") (title "init-course-plan") (form (init-course-plan))) ((kind "manual-page") (description "Write the plan of a given lecture to a html file.
The id parameter is mandator. The keyword parameters are each of the form
(key value), where key is one of literature, guide, exercises, references, and misc.
The function writes the plan to an HTML file in the course html directory. The name of the
files will be identical to the name of the LAML file, in which the source (with the lecture-plan form) is located.
This function the central function for generation of individual lecture plans for lectures in the cource.
") (title "lecture-plan") (form (lecture-plan id . keyword-parameters))) ((kind "manual-section") (section-title "Colors.") (section-body "The graphical idea of the course home page is to show the left frame in a dark color
with white text, and the right large main frame in a light color with black text.
The course plan document style supports color styles in terms of related colors and (currently) a single gif image file.
You can make a new color scheme, and you can apply an existing color scheme.

")) ((kind "manual-page") (description "The color used to mark course entries in the calendar.
") (title "course-calendar-color") (form course-calendar-color)) ((kind "manual-page") (description "Return a color scheme in terms of a dark color (background of left frame), dark text color,
light color (background of large right frame) and a gif triangle file name (usually in the dark color).
") (title "make-color-scheme") (form (make-color-scheme dark dark-text light triangle-image))) ((kind "manual-page") (description "Apply a given color scheme
") (title "apply-course-plan-color-scheme") (form (apply-course-plan-color-scheme color-scheme))) ((kind "manual-page") (description "A sample color scheme: Purple and yellow
") (title "course-plan-color-scheme-1") (form course-plan-color-scheme-1)) ((kind "manual-page") (description "Another sample color scheme: Read and yellow.
") (title "course-plan-color-scheme-2") (form course-plan-color-scheme-2)) ((kind "manual-page") (description "Another sample color scheme: Black and white.
") (title "course-plan-color-scheme-3") (form course-plan-color-scheme-3)) ((kind "manual-page") (description "Another sample color scheme:  Blue and grey.
") (title "course-plan-color-scheme-4") (form course-plan-color-scheme-4)) ((kind "manual-page") (description "Another sample color scheme:  Blue and grey.
") (title "course-plan-color-scheme-5") (form course-plan-color-scheme-5)) ((kind "manual-page") (description "Return a string which tells about the generating computer system.
Default: the empty string.
") (title "generating-system") (form (generating-system))) ((kind "manual-section") (section-title "Course overviews.") (section-body "This sections contains a single function which generates convenient overviews of a course, including
the 'home page' of the course. A call of this function is typically made by the LAML file which produces
the course introduction, which must have the name \"course-introduction\".

")) ((kind "manual-page") (description "Export this course's calendar entries to to-file.
Only this course's entries are exported. The export format is the 'native' calendar format,
as defined by the interactive, server-based LAML calendar tool. URL's to lectures are made absolute via the exporting.
If to-file exists, overwrite it.
") (title "export-course-calendar-entries") (form (export-course-calendar-entries to-file))) ((kind "manual-page") (description "Make course overview pages, including the course home page, and the course calendar.
home-page-name is the name of the home page file, without extension and without path information.
cal-year, cal-month, and cal-number-of-months determine the calendar range.
cal-title is used to define the title of the calendar.
external-calendar-entries is used to pass additional calendar entries to the course calendar (a list of entries).
The entries must be in the 'calendar-events' format, as documented in the LAML calendar tool.
") (title "make-course-overview-pages") (form (make-course-overview-pages home-page-name cal-year cal-month cal-number-of-months cal-title external-calendar-entries))) ((kind "manual-section") (section-title "Course plan exercise functions.") (section-body "The course-exercise function may, for instance, be called after the lecture-plan function in order to
define an excercise for the lecture. Each exercise is written on a separate HTML file. The URL function 
course-exercise-ref can be used to refer to the exercises from the lecture-plan.

")) ((kind "manual-page") (description "Define an exercise with a certain id (symbol), a number, and a body.
The exercise belongs to lecture-id, which is optional in cases the course-exercise follows a lecture-plan clause.
id is a symbol identifying the execise. 
number is the execise number or letter.
") (title "course-exercise") (form (course-exercise id number body . lecture-id))) ((kind "manual-page") (description "Return an URL to an exercise.
The URL is relative, and only works from HTML files in the course html directory.
id is a symbol identifying the execise. 
number is the execise number, a letter or an integer.
lecture-id identifies the lecture, to which the exercise belongs.
The function return a link to the exercise, and it is
only applicable from a lecture plan page. See the function exercise-url for an absolute url.
") (title "course-exercise-ref") (form (course-exercise-ref id number lecture-id))) ((kind "manual-section") (section-title "URL functions.") (section-body "These functions define a few useful URL functions. The user is encouraged to write more such
functions in the course description file.

")) ((kind "manual-page") (description "Return a relative URL to a particular lecture page (as generated by the lecture-plan function).
") (title "us-relative-url") (form (us-relative-url id))) ((kind "manual-page") (description "Return an absolute URL to a particular exercise.
") (title "exercise-url") (form (exercise-url lecture-id exercise-id))) ((kind "manual-page") (description "Return an absolute URL to lecture number n in this course.
") (title "lecture-number-url") (form (lecture-number-url n))) ((kind "manual-section") (section-title "Internal functions of interest.") (section-body "Here we wil document a few internal functions which may turn out to be useful in some contexts.

")) ((kind "manual-page") (description "Return a course page (with standard graphical elements, header, body and some footer stuff (standard-links)).
This functions returns an HTML string.
Use this function together with write-course-html-file if you want to make additional course plan files.
") (title "course-page") (form (course-page title body))) ((kind "manual-page") (description "Write the contents in the course's html file.
The contents is typcically an activation of course-page.
File is without extension and without any path information.
This function adds an html extension.
Use this function together course-page if you want to make additional course plan files.
") (title "write-course-html-file") (form (write-course-html-file contents file))) ((kind "manual-section") (section-title "Utility functions.") (section-body "Here are some functions which are useful when producing course home pages.

")) ((kind "manual-page") (description "Return a list of times, length n, starting with start, and with the period period.
This function can be used to produce the time-list in case of a regular course rythm.
") (title "periodic") (form (periodic start n period))) ((kind "manual-section") (section-title "An example of a course home page") (section-body "One of the best ways to learn about the course plan document style is to study an example.
                As part of the LAML example collection we also provide a <a href = \"../../../examples/course-plan/index.html\">course plan example</a>, where you
                can see the Scheme and LAML sources together with the generated HTML pages.")) ((kind "manual-section") (section-title "Template stuff") (section-body "If you are going to create a course home page via use of the LAML course plan document style
                the template described in this section is a possible starting point. We have made a <a href = \"template/\">directory structure</a> with templates of all the central elements. The capitalized names should be filled in 
                by you.
                It is possible generate the 'template course' once the course-dir in course-description.scm has been defined.
                The <a href = \"template/html/COURSE-HOME.html\">resulting course home page</a> does not look nice, but it may be instructive to take a look at it anyway.
                The resulting HTML files can be navigated to above, but they are not part of the zip file.
                We have also made a <a href = \"template.zip\">zipped version of the template directory</a> for your convenience. 
                You can unzip it into the parent directory, in which you want your course home page to reside. It creates a course directory called 'template'.
                Afterwards, rename 'template' to something which makes sense.")))